<?php
$lang['error_insufficientparams'] = 'Yetersiz (veya boş) parametre';
$lang['error_duplicatename'] = 'Bu ada sahip bir &ouml;ğe zaten var';
$lang['detail_page'] = 'Ayrıntı Sayfası';
$lang['detail_template'] = 'Ayrıntı Şablonu';
$lang['warning_preview'] = 'Warning: This preview panel behaves much like a browser window allowing you to navigate away from the initially previewed page. However, if you do that, you may experience unexpected behaviour.  Navigating away from the initial page and returning will not give the expected results.<br/><strong>Note:</strong> The preview does not upload files you may have selected for upload.';
$lang['article'] = 'Makale';
$lang['preview'] = '&Ouml;nizleme';
$lang['info_detail_returnid'] = 'This preference is used to determine a page (and therefore a template) to use to view detail pages.  Individualized News Detail URLS will not work if this parameter is not set to a valid page.  Additionally, if this preference is set, and no detailpage parameter is provided on the news tag, then this value will be used for detail links';
$lang['title_detail_returnid'] = 'Ayrıntılı g&ouml;r&uuml;n&uuml;m i&ccedil;in varsayılan sayfa';
$lang['title_submission_settings'] = 'Haber Giriş Ayarları';
$lang['title_fesubmit_settings'] = '&Ouml;n sayfa ekleme ayarları';
$lang['title_notification_settings'] = 'Bilgilendirme Ayarları';
$lang['title_detail_settings'] = 'Ayrıntılı G&ouml;r&uuml;n&uuml;m Ayarları';
$lang['error_invalidurl'] = 'Ge&ccedil;ersiz URL <em> (zaten kullanılmış veya ge&ccedil;ersiz karakter i&ccedil;eriyor) </ em>';
$lang['url'] = 'URL';
$lang['expired_searchable'] = 'S&uuml;resi bitmiş haberler arama sonu&ccedil;larında &ccedil;ıkabilsin';
$lang['helpshowall'] = 'Bitiş tarihine bakılmaksızın t&uuml;m haberleri g&ouml;ster';
$lang['error_invaliddates'] = 'Bir yada daha fazla tarih yanlış girirldi';
$lang['notify_n_draft_items_sub'] = '%d Haber Yazıları(s)';
$lang['notify_n_draft_items'] = '%s sayıda yayınalnmamış haber var';
$lang['unlimited'] = 'Limitsiz';
$lang['none'] = 'Yok';
$lang['anonymous'] = 'Anonim';
$lang['unknown'] = 'Bilinmiyor';
$lang['fesubmit_redirect'] = 'PageID or alias to redirect to after a news article has been submitted via the fesubmit action';
$lang['allow_summary_wysiwyg'] = '&Ouml;zet alanında WYSIWYG editore izin ver';
$lang['title_browsecat_template'] = 'Browse Category Template Editor';
$lang['title_browsecat_sysdefault'] = 'Default Browse category Template';
$lang['browsecattemplate'] = 'Kategori şablonları';
$lang['error_filesize'] = 'Y&uuml;klenen dosyanın boyutu izin verilen dosya boyutundan fazla';
$lang['post_date_desc'] = 'G&ouml;nderim Tarihi Azalan';
$lang['post_date_asc'] = 'G&ouml;nderim Tarihi Artan';
$lang['expiry_date_desc'] = 'Ge&ccedil;erlilik Tarihi Azalan';
$lang['expiry_date_asc'] = 'Ger&ccedil;erlilik Tarihi Artan';
$lang['title_desc'] = 'Başlığa G&ouml;re Azalan';
$lang['title_asc'] = 'Başlığa G&ouml;re Artan';
$lang['status_desc'] = 'Duruma G&ouml;re Azalan';
$lang['status_asc'] = 'Duruma G&ouml;re Azalan';
$lang['fesubmit_status'] = 'The status of news articles submitted via the frontend';
$lang['error_invalidfiletype'] = 'Bu dosya tipini y&uuml;kleyemezsiniz';
$lang['error_upload'] = 'Dosya y&uuml;kleme hatası oluştu';
$lang['error_movefile'] = 'Dosya oluşturulamadı: %s';
$lang['error_mkdir'] = 'Klas&ouml;r oluşturulamadı: %s';
$lang['expiry_interval'] = 'The number of days (by default) before an article expires (if expiry is selected)';
$lang['removed'] = 'Geri Alındı';
$lang['msg_contenttype_removed'] = 'The news content type has been removed.  Please place {news} tags with appropriate parameters into your page template or into your page content to replace this functionality.';
$lang['delete_selected'] = 'Se&ccedil;ilen Haberleri Sil';
$lang['areyousure_deletemultiple'] = 'Se&ccedil;ilen haberleri kalıcı olarak silmek istediğinize emin misiniz? Bu durum geri alınamaz!';
$lang['error_templatenamexists'] = 'Şablon adı zaten var';
$lang['error_noarticlesselected'] = 'Hi&ccedil; Haber Se&ccedil;ilmedi';
$lang['reassign_category'] = 'Kategori değiştir';
$lang['select'] = 'Se&ccedil;iniz';
$lang['approve'] = 'Durumu &#039;Yayınlandı&#039; olarak değiştir';
$lang['revert'] = 'Durumu &#039;Taslak&#039; olarak değiştir';
$lang['hide_summary_field'] = 'Hide the summary field when adding or editing articles';
$lang['textbox'] = 'Text Input';
$lang['checkbox'] = 'Checkbox';
$lang['textarea'] = 'Text Area';
$lang['file'] = 'Dosya';
$lang['auto_create_thumbnails'] = 'Automatically create thumbnail files for files with these extensions';
$lang['allowed_upload_types'] = 'Allow only files with these extensions to be uploaded';
$lang['fielddefupdated'] = 'Alan Tanımı G&uuml;ncellendi';
$lang['editfielddef'] = 'Alan Tanımı D&uuml;zenle';
$lang['up'] = 'Yukarı';
$lang['down'] = 'Aşağı';
$lang['fielddefdeleted'] = 'Tanımlanan Alan Silindi';
$lang['nameexists'] = 'Tanımlı alan adı zaten var';
$lang['notanumber'] = 'Maksimum Uzunluk Sayı Değil';
$lang['fielddef'] = 'Alan Tanımlama';
$lang['fielddefadded'] = 'Alan Tanımı Eklendi';
$lang['public'] = 'Genel';
$lang['type'] = 'Tip';
$lang['info_maxlength'] = 'Maksimum uzunluğu yalnızca metin giriş alanları i&ccedil;in ge&ccedil;erlidir.';
$lang['maxlength'] = 'Maksimum Uzunluk';
$lang['addfielddef'] = 'Alan Ekle';
$lang['customfields'] = 'Alan Tanımlamaları';
$lang['deprecated'] = 'desteklenmiyor';
$lang['subject_newnews'] = 'Yeni bir haber makalesi g&ouml;nderildi';
$lang['email_subject'] = 'The Subject of the outgoing email';
$lang['email_template'] = 'The format of the email message';
$lang['formsubmit_emailaddress'] = 'Email address to receive notification of news submission';
$lang['extra'] = 'Ekstra';
$lang['uploadscategory'] = 'Y&uuml;klemeler Kategorisi';
$lang['title_available_templates'] = 'Kullanılabilir Şablonlar';
$lang['resettodefault'] = 'Varsayılan Ayarlara Geri D&ouml;n';
$lang['title_form_template'] = 'Form Şablonu Edit&ouml;r&uuml;';
$lang['title_detail_template'] = 'Ayrıntı Şablon Edit&ouml;r&uuml;';
$lang['title_summary_template'] = '&Ouml;zet Şablon Edit&ouml;r&uuml;';
$lang['prompt_templatename'] = 'Şablon Adı';
$lang['prompt_template'] = 'Şablon Kaynağı';
$lang['title_form_sysdefault'] = 'Varsayılan Form Şablonu';
$lang['title_summary_sysdefault'] = 'Varsayılan &Ouml;zet Şablonu';
$lang['title_detail_sysdefault'] = 'Varsayılan Ayrıntı Şablonu';
$lang['info_sysdefault2'] = '<strong>Note:</strong> This tab contains text areas to allow you to edit a set of templates that are displayed when you create a &#039;new&#039; summary, detail, or form template.  Changing content in this tab, and clicking &#039;submit&#039; will <strong>not effect any current displays</strong>.';
$lang['info_sysdefault'] = '<em>(the content used by default when a new template is created)</em>';
$lang['template'] = 'Şablon';
$lang['prompt_name'] = 'Adı';
$lang['prompt_default'] = 'Varsayılan';
$lang['prompt_newtemplate'] = 'Yeni Şablon Yarat';
$lang['help_pagelimit'] = 'Maximum number of items to display (per page).  If this parameter is not supplied all matching items will be displayed.  If it is, and there are more items available than specified in the pararamter, text and links will be supplied to allow scrolling through the results';
$lang['prompt_page'] = 'Sayfa';
$lang['firstpage'] = '<<';
$lang['prevpage'] = '<';
$lang['nextpage'] = '>';
$lang['lastpage'] = '>>';
$lang['prompt_of'] = '-';
$lang['prompt_pagelimit'] = 'Sayfa Limiti';
$lang['prompt_sorting'] = 'Sırala';
$lang['title_filter'] = 'Filtreler';
$lang['published'] = 'Yayınlandı';
$lang['draft'] = 'Taslak';
$lang['expired'] = 'S&uuml;resi Dolmuş';
$lang['author'] = 'Yazar';
$lang['sysdefaults'] = 'Varsayılanlara d&ouml;n';
$lang['restoretodefaultsmsg'] = 'Bu işlem şablon i&ccedil;eriğini sistem varsayılanlarına &ccedil;evirecektir. Devam etmek istediğinizden emin misiniz?';
$lang['addarticle'] = 'Haber Ekle';
$lang['articleadded'] = 'Haber başarılı olarak eklendi.';
$lang['articleupdated'] = 'Haber başarılı olarak g&uuml;ncellendi.';
$lang['articledeleted'] = 'Haber başarılı olarak silindi.';
$lang['addcategory'] = 'Kategori Ekle';
$lang['categoryadded'] = 'Kategori başarılı olarak eklendi.';
$lang['categoryupdated'] = 'Kategori başarılı olarak g&uuml;ncellendi.';
$lang['categorydeleted'] = 'Kategori başarılı olarak silindi.';
$lang['addnewsitem'] = 'Haber &Ouml;ğesi Ekle';
$lang['allcategories'] = 'T&uuml;m Kategoriler';
$lang['allentries'] = 'T&uuml;m Girdiler';
$lang['areyousure'] = 'Silmek istediğinizden emin misiniz?';
$lang['articles'] = 'Haberler';
$lang['cancel'] = 'Vazge&ccedil;';
$lang['category'] = 'Kategori';
$lang['categories'] = 'Kategoriler';
$lang['default_category'] = 'Varsayılan kategori';
$lang['content'] = 'İ&ccedil;erik';
$lang['dateformat'] = '%s ge&ccedil;erli bir yyyy-mm-dd hh:mm:ss bi&ccedil;imi değil';
$lang['delete'] = 'Sil';
$lang['description'] = 'Haber girdileri ekle, d&uuml;zenle ve sil';
$lang['formtemplate'] = 'Form Şablonları';
$lang['detailtemplate'] = 'Ayrıntı Şablonu';
$lang['default_templates'] = 'Varsayılan Şablonlar';
$lang['detailtemplateupdated'] = 'D&uuml;zenlenen Ayrıntı Şablonu başarılı olarak veritabanına kaydedildi.';
$lang['displaytemplate'] = 'Şablonu G&ouml;ster';
$lang['edit'] = 'D&uuml;zenle';
$lang['enddate'] = 'Bitiş Tarihi';
$lang['endrequiresstart'] = 'Bitiş tarihihi girmek başlangı&ccedil; tarihini girmeyi de gerektirir';
$lang['entries'] = '%s Girdi';
$lang['status'] = 'Durum';
$lang['expiry'] = 'S&uuml;resi';
$lang['filter'] = 'S&uuml;z';
$lang['more'] = 'Devamı';
$lang['category_label'] = 'Kategori:';
$lang['author_label'] = 'G&ouml;nderen:';
$lang['extra_label'] = 'Ekstra:';
$lang['moretext'] = 'Fazla yazı';
$lang['name'] = 'İsim';
$lang['news'] = 'Haberler';
$lang['news_return'] = 'Geri d&ouml;n';
$lang['newcategory'] = 'Yeni Kategori';
$lang['needpermission'] = 'Bu işlemi yapmak i&ccedil;in &#039;%s&#039; yetkinizin olması gerekir.';
$lang['nocategorygiven'] = 'Kategori girilmemiş';
$lang['startdatetoolate'] = 'Başlangı&ccedil; ​​Tarihi bitiş tarihinden sonra olamaz';
$lang['nocontentgiven'] = 'İ&ccedil;erik girilmemiş';
$lang['noitemsfound'] = 'Kategori i&ccedil;in <strong>hi&ccedil;</strong> &ouml;ğe bulunamadı: %s';
$lang['nopostdategiven'] = 'G&ouml;nderme Tarihi girilmemiş';
$lang['note'] = '<em>Not:</em> Tarihler &#039;yyyy-mm-dd hh:mm:ss&#039; bi&ccedil;iminde olmalıdır.';
$lang['notitlegiven'] = 'Başlık girilmemiş';
$lang['nonamegiven'] = 'İsim girilmemiş';
$lang['numbertodisplay'] = 'G&ouml;sterilecek adet (boş bırakılırsa t&uuml;m kayıtlar g&ouml;sterilir)';
$lang['print'] = 'Yazdır';
$lang['postdate'] = 'G&ouml;nderme Tarihi';
$lang['postinstall'] = 'Make sure to set the &quot;Modify News&quot; permission on users who will be administering News items.';
$lang['selectcategory'] = 'Kategori Se&ccedil;in';
$lang['showchildcategories'] = 'Alt kategorileri g&ouml;ster';
$lang['sortascending'] = 'B&uuml;y&uuml;kten k&uuml;&ccedil;&uuml;ğe sırala';
$lang['startdate'] = 'Başlangı&ccedil; Tarihi';
$lang['startoffset'] = 'n&#039;inci &ouml;ğeden başlayarak g&ouml;ster';
$lang['startrequiresend'] = 'Başlangı&ccedil; tarihini girmek bitiş tarihini de girmeyi gerektirir';
$lang['apply'] = 'Uygula';
$lang['submit'] = 'G&ouml;nder';
$lang['summary'] = '&Ouml;zet';
$lang['summarytemplate'] = '&Ouml;zet Şablonu';
$lang['summarytemplateupdated'] = 'Haber &Ouml;zet Şablonu başarılı olarak g&uuml;ncellendi.';
$lang['title'] = 'Başlık';
$lang['options'] = 'Se&ccedil;enekler';
$lang['optionsupdated'] = 'Se&ccedil;enekler başarılı olarak g&uuml;ncellendi.';
$lang['useexpiration'] = 'S&uuml;resi ge&ccedil;me tarihini kullan';
$lang['eventdesc-NewsArticleAdded'] = 'Haber eklendiğinde g&ouml;nderildi.';
$lang['eventhelp-NewsArticleAdded'] = '<p>Sent when an article is added.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;news_id\&quot; - Id of the news article</li>
<li>\&quot;category_id\&quot; - Id of the category for this article</li>
<li>\&quot;title\&quot; - Title of the article</li>
<li>\&quot;content\&quot; - Content of the article</li>
<li>\&quot;summary\&quot; - Summary of the article</li>
<li>\&quot;status\&quot; - Status of the article (&quot;draft&quot; or &quot;publish&quot;)</li>
<li>\&quot;start_time\&quot; - Date the article should start being displayed</li>
<li>\&quot;end_time\&quot; - Date the article should stop being displayed</li>
<li>\&quot;useexp\&quot; - Whether the expiration date should be ignored or not</li>
</ul>
';
$lang['eventdesc-NewsArticleEdited'] = 'Haber d&uuml;zenlendiğinde g&ouml;nderildi.';
$lang['eventhelp-NewsArticleEdited'] = '<p>Sent when an article is edited.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;news_id\&quot; - Id of the news article</li>
<li>\&quot;category_id\&quot; - Id of the category for this article</li>
<li>\&quot;title\&quot; - Title of the article</li>
<li>\&quot;content\&quot; - Content of the article</li>
<li>\&quot;summary\&quot; - Summary of the article</li>
<li>\&quot;status\&quot; - Status of the article (&quot;draft&quot; or &quot;publish&quot;)</li>
<li>\&quot;start_time\&quot; - Date the article should start being displayed</li>
<li>\&quot;end_time\&quot; - Date the article should stop being displayed</li>
<li>\&quot;useexp\&quot; - Whether the expiration date should be ignored or not</li>
</ul>
';
$lang['eventdesc-NewsArticleDeleted'] = 'Haber silindiğinde g&ouml;nderildi.';
$lang['eventhelp-NewsArticleDeleted'] = '<p>Sent when an article is deleted.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;news_id\&quot; - Id of the news article</li>
</ul>
';
$lang['eventdesc-NewsCategoryAdded'] = 'Kategori eklendiğinde g&ouml;nderildi.';
$lang['eventhelp-NewsCategoryAdded'] = '<p>Sent when a category is added.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;category_id\&quot; - Id of the news category</li>
<li>\&quot;name\&quot; - Name of the news category</li>
</ul>
';
$lang['eventdesc-NewsCategoryEdited'] = 'Kategori d&uuml;zenlendiğinde g&ouml;nderildi.';
$lang['eventhelp-NewsCategoryEdited'] = '<p>Sent when a category is edited.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;category_id\&quot; - Id of the news category</li>
<li>\&quot;name\&quot; - Name of the news category</li>
<li>\&quot;origname\&quot; - The original name of the news category</li>
</ul>
';
$lang['eventdesc-NewsCategoryDeleted'] = 'Kategori silindiğinde g&ouml;nderildi.';
$lang['eventhelp-NewsCategoryDeleted'] = '<p>Sent when a category is deleted.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;category_id\&quot; - Id of the deleted category </li>
<li>\&quot;name\&quot; - Name of the deleted category</li>
</ul>
';
$lang['help_articleid'] = 'This parameter is only applicable to the detail view.  It allows specifying which news article to display in detail mode.  If the special value -1 is used, the system will display the newest, published, non expired article.';
$lang['helpnumber'] = 'G&ouml;sterilecek &ouml;ğe sayısı =- boş bırakılırsa t&uuml;m &ouml;ğeler g&ouml;sterilir.';
$lang['helpstart'] = 'Başlangı&ccedil; &ouml;ğe sayısı -- boş bırakılırsa ilk &ouml;ğeden başlanır.';
$lang['helpcategory'] = 'Only display items for that category. <b>Use * after the name to show children.</b>  Multiple categories can be used if separated with a comma. Leaving empty, will show all categories.';
$lang['helpmoretext'] = 'Text to display at the end of a news item if it goes over the summary length.  Defaults to &quot;more...&quot;';
$lang['helpsummarytemplate'] = 'Use a separate template for displaying the article summary.  It have to live in modules/News/templates.';
$lang['helpformtemplate'] = 'Use a database template for displaying the article submission form. This template must exist and be visible in the form templates tab of the News admin, though it does not need to be the default.  If this parameter is not specified, then the current template marked as default will be used.';
$lang['helpbrowsecattemplate'] = 'Use a database template for displaying the category browser. This template must exist and be visible in the Browse Category Templates tab of the News admin, though it does not need to be the default.  If this parameter is not specified, then the current template marked as default will be used.';
$lang['helpdetailtemplate'] = 'Use a separate template for displaying the article detail.  It have to live in modules/News/templates.';
$lang['helpsortby'] = 'Field to sort by.  Options are: &quot;news_date&quot;, &quot;summary&quot;, &quot;news_data&quot;, &quot;news_category&quot;, &quot;news_title&quot;.  Defaults to &quot;news_date&quot;.';
$lang['helpsortasc'] = 'Sort news items in ascending date order rather than descending.';
$lang['helpdetailpage'] = 'Page to display News details in.  This can either be a page alias or an id. Used to allow details to be displayed in a different template from the summary.';
$lang['helpshowarchive'] = 'Sadece s&uuml;resi ge&ccedil;miş haberleri g&ouml;ster.';
$lang['helpbrowsecat'] = 'Taranabilir kategori listesini g&ouml;ster.';
$lang['helpaction'] = 'Override the default action.  Possible values are &#039;default&#039; to display the summary view, and &#039;fesubmit&#039; to display the frontend form for allowing users to submit news articles on the front end.';
$lang['help'] = '	<h3>What does this do?</h3>
	<p>News is a module for displaying news events on your page, similar to a blog style, except with more features!.  When the module is installed, a News admin page is added to administration menu that will allow you to select or add a news category.  Once a news category is created or selected, a list of news items for that category will be displayed.  From here, you can add, edit or delete news items for that category.</p>
	<h3>Template variables</h3>
	<ul>
		<li><b>itemcount</b> - The number of news articles to be shown.</li>
		<li><b>entry->authorname</b> - The full name of the the author including First and Last name.</li>
	</ul>
	<h3>Security</h3>
	<p>The user must belong to a group with the &#039;Modify News&#039; permission in order to add, edit, or delete News entries.</p>
	<p>In order to edit the layout templates, the user must belong to a group with the &#039;Modify Templates&#039; permission.</p>
	<p>In order to edit the global news preferences, the user must belong to a group with the &#039;Modify Site Preferences&#039; permission.</p>
	<h3>How do I use it?</h3>
	<p>The easiest way to use it is with the {news} wrapper tag (wraps the module in a tag, to simplify the syntax).  This will insert the module into your template or page anywhere you wish, and display news items.  The code would look something like: <code>{news number=&#039;5&#039;}</code></p>';
$lang['utmz'] = '156861353.1341774084.2.2.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/project/latest_files.html';
$lang['utma'] = '156861353.21813627.1341772112.1341774084.1341779249.3';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>